==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/AssetParentHierarchy.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;choice minOccurs="0">
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}AssetDependency" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}PositionDependency" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}PrimarySystemDependency" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}SystemDependency" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}LocationDependency" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}NonDependentParents" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "assetid",
    "type",
    "locationid",
    "assetDependency",
    "positionDependency",
    "primarySystemDependency",
    "systemDependency",
    "locationDependency",
    "nonDependentParents"
})
@XmlRootElement(name = "AssetParentHierarchy")
public class AssetParentHierarchy {

    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "AssetDependency")
    protected AssetDependency assetDependency;
    @XmlElement(name = "PositionDependency")
    protected PositionDependency positionDependency;
    @XmlElement(name = "PrimarySystemDependency")
    protected PrimarySystemDependency primarySystemDependency;
    @XmlElement(name = "SystemDependency")
    protected SystemDependency systemDependency;
    @XmlElement(name = "LocationDependency")
    protected LocationDependency locationDependency;
    @XmlElement(name = "NonDependentParents")
    protected NonDependentParents_Type nonDependentParents;

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the locationid property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Sets the value of the locationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Gets the value of the assetDependency property.
     * 
     * @return
     *     possible object is
     *     {@link AssetDependency }
     *     
     */
    public AssetDependency getAssetDependency() {
        return assetDependency;
    }

    /**
     * Sets the value of the assetDependency property.
     * 
     * @param value
     *     allowed object is
     *     {@link AssetDependency }
     *     
     */
    public void setAssetDependency(AssetDependency value) {
        this.assetDependency = value;
    }

    /**
     * Gets the value of the positionDependency property.
     * 
     * @return
     *     possible object is
     *     {@link PositionDependency }
     *     
     */
    public PositionDependency getPositionDependency() {
        return positionDependency;
    }

    /**
     * Sets the value of the positionDependency property.
     * 
     * @param value
     *     allowed object is
     *     {@link PositionDependency }
     *     
     */
    public void setPositionDependency(PositionDependency value) {
        this.positionDependency = value;
    }

    /**
     * Gets the value of the primarySystemDependency property.
     * 
     * @return
     *     possible object is
     *     {@link PrimarySystemDependency }
     *     
     */
    public PrimarySystemDependency getPrimarySystemDependency() {
        return primarySystemDependency;
    }

    /**
     * Sets the value of the primarySystemDependency property.
     * 
     * @param value
     *     allowed object is
     *     {@link PrimarySystemDependency }
     *     
     */
    public void setPrimarySystemDependency(PrimarySystemDependency value) {
        this.primarySystemDependency = value;
    }

    /**
     * Gets the value of the systemDependency property.
     * 
     * @return
     *     possible object is
     *     {@link SystemDependency }
     *     
     */
    public SystemDependency getSystemDependency() {
        return systemDependency;
    }

    /**
     * Sets the value of the systemDependency property.
     * 
     * @param value
     *     allowed object is
     *     {@link SystemDependency }
     *     
     */
    public void setSystemDependency(SystemDependency value) {
        this.systemDependency = value;
    }

    /**
     * Gets the value of the locationDependency property.
     * 
     * @return
     *     possible object is
     *     {@link LocationDependency }
     *     
     */
    public LocationDependency getLocationDependency() {
        return locationDependency;
    }

    /**
     * Sets the value of the locationDependency property.
     * 
     * @param value
     *     allowed object is
     *     {@link LocationDependency }
     *     
     */
    public void setLocationDependency(LocationDependency value) {
        this.locationDependency = value;
    }

    /**
     * Gets the value of the nonDependentParents property.
     * 
     * @return
     *     possible object is
     *     {@link NonDependentParents_Type }
     *     
     */
    public NonDependentParents_Type getNonDependentParents() {
        return nonDependentParents;
    }

    /**
     * Sets the value of the nonDependentParents property.
     * 
     * @param value
     *     allowed object is
     *     {@link NonDependentParents_Type }
     *     
     */
    public void setNonDependentParents(NonDependentParents_Type value) {
        this.nonDependentParents = value;
    }

}

==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/AssetParentHierarchy.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}POSITIONPARENT" minOccurs="0"/>
 *         &lt;choice minOccurs="0">
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}AssetDependency" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}PositionDependency" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}PrimarySystemDependency" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}SystemDependency" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}LocationDependency" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}NonDependentParents" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "assetid",
    "type",
    "locationid",
    "positionparent",
    "assetDependency",
    "positionDependency",
    "primarySystemDependency",
    "systemDependency",
    "locationDependency",
    "nonDependentParents"
})
@XmlRootElement(name = "AssetParentHierarchy")
public class AssetParentHierarchy {

    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "POSITIONPARENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String positionparent;
    @XmlElement(name = "AssetDependency")
    protected AssetDependency assetDependency;
    @XmlElement(name = "PositionDependency")
    protected PositionDependency positionDependency;
    @XmlElement(name = "PrimarySystemDependency")
    protected PrimarySystemDependency primarySystemDependency;
    @XmlElement(name = "SystemDependency")
    protected SystemDependency systemDependency;
    @XmlElement(name = "LocationDependency")
    protected LocationDependency locationDependency;
    @XmlElement(name = "NonDependentParents")
    protected NonDependentParents_Type nonDependentParents;

    /**
     * Obtient la valeur de la propriété assetid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Définit la valeur de la propriété assetid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Obtient la valeur de la propriété locationid.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Définit la valeur de la propriété locationid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Obtient la valeur de la propriété positionparent.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPOSITIONPARENT() {
        return positionparent;
    }

    /**
     * Définit la valeur de la propriété positionparent.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPOSITIONPARENT(String value) {
        this.positionparent = value;
    }

    /**
     * Obtient la valeur de la propriété assetDependency.
     * 
     * @return
     *     possible object is
     *     {@link AssetDependency }
     *     
     */
    public AssetDependency getAssetDependency() {
        return assetDependency;
    }

    /**
     * Définit la valeur de la propriété assetDependency.
     * 
     * @param value
     *     allowed object is
     *     {@link AssetDependency }
     *     
     */
    public void setAssetDependency(AssetDependency value) {
        this.assetDependency = value;
    }

    /**
     * Obtient la valeur de la propriété positionDependency.
     * 
     * @return
     *     possible object is
     *     {@link PositionDependency }
     *     
     */
    public PositionDependency getPositionDependency() {
        return positionDependency;
    }

    /**
     * Définit la valeur de la propriété positionDependency.
     * 
     * @param value
     *     allowed object is
     *     {@link PositionDependency }
     *     
     */
    public void setPositionDependency(PositionDependency value) {
        this.positionDependency = value;
    }

    /**
     * Obtient la valeur de la propriété primarySystemDependency.
     * 
     * @return
     *     possible object is
     *     {@link PrimarySystemDependency }
     *     
     */
    public PrimarySystemDependency getPrimarySystemDependency() {
        return primarySystemDependency;
    }

    /**
     * Définit la valeur de la propriété primarySystemDependency.
     * 
     * @param value
     *     allowed object is
     *     {@link PrimarySystemDependency }
     *     
     */
    public void setPrimarySystemDependency(PrimarySystemDependency value) {
        this.primarySystemDependency = value;
    }

    /**
     * Obtient la valeur de la propriété systemDependency.
     * 
     * @return
     *     possible object is
     *     {@link SystemDependency }
     *     
     */
    public SystemDependency getSystemDependency() {
        return systemDependency;
    }

    /**
     * Définit la valeur de la propriété systemDependency.
     * 
     * @param value
     *     allowed object is
     *     {@link SystemDependency }
     *     
     */
    public void setSystemDependency(SystemDependency value) {
        this.systemDependency = value;
    }

    /**
     * Obtient la valeur de la propriété locationDependency.
     * 
     * @return
     *     possible object is
     *     {@link LocationDependency }
     *     
     */
    public LocationDependency getLocationDependency() {
        return locationDependency;
    }

    /**
     * Définit la valeur de la propriété locationDependency.
     * 
     * @param value
     *     allowed object is
     *     {@link LocationDependency }
     *     
     */
    public void setLocationDependency(LocationDependency value) {
        this.locationDependency = value;
    }

    /**
     * Obtient la valeur de la propriété nonDependentParents.
     * 
     * @return
     *     possible object is
     *     {@link NonDependentParents_Type }
     *     
     */
    public NonDependentParents_Type getNonDependentParents() {
        return nonDependentParents;
    }

    /**
     * Définit la valeur de la propriété nonDependentParents.
     * 
     * @param value
     *     allowed object is
     *     {@link NonDependentParents_Type }
     *     
     */
    public void setNonDependentParents(NonDependentParents_Type value) {
        this.nonDependentParents = value;
    }

}
